pub struct Cursor {
pub height: BlockHeight,
pub index: u32,
}Expand description
A logical position in a chain’s stream of outgoing messages: the height of the block that produced the message and the index of the message-producing transaction within that block.
Fields
height: BlockHeightThe height of the producing block.
index: u32The transaction index within the block.
Implementations
Sourceimpl Cursor
impl Cursor
pub async fn height( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&BlockHeight, Error>
pub async fn index( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&u32, Error>
Sourceimpl Cursor
impl Cursor
Sourcepub fn try_add_one(self) -> Result<Cursor, ArithmeticError>
pub fn try_add_one(self) -> Result<Cursor, ArithmeticError>
Returns the cursor pointing to the next position within the same block, or
ArithmeticError::Overflow if index is already at the maximum.