pub struct U128(pub u128);Expand description
A u128 newtype that serializes as a decimal string in human-readable
formats (JSON / GraphQL) and as a bare u128 in binary (BCS).
Tuple Fields
0: u128Trait Implementations
Sourceimpl<'de> Deserialize<'de> for U128
impl<'de> Deserialize<'de> for U128
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<U128, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<U128, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl InputType for U128
impl InputType for U128
Sourcetype RawValueType = U128
type RawValueType = U128
The raw type used for validator. Read more
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourcefn parse(value: Option<ConstValue>) -> Result<U128, InputValueError<U128>>
fn parse(value: Option<ConstValue>) -> Result<U128, InputValueError<U128>>
Parse from
Value. None represents undefined.Sourcefn to_value(&self) -> ConstValue
fn to_value(&self) -> ConstValue
Convert to a
Value for introspection.Sourcefn as_raw_value(&self) -> Option<&<U128 as InputType>::RawValueType>
fn as_raw_value(&self) -> Option<&<U128 as InputType>::RawValueType>
Returns a reference to the raw value.
Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl Ord for U128
impl Ord for U128
Sourceimpl OutputType for U128
impl OutputType for U128
Sourcefn create_type_info(registry: &mut Registry) -> String
fn create_type_info(registry: &mut Registry) -> String
Create type information in the registry and return qualified typename.
Sourceasync fn resolve(
&self,
_: &ContextBase<'_, &Positioned<SelectionSet>>,
_field: &Positioned<Field>,
) -> Result<ConstValue, ServerError>
async fn resolve( &self, _: &ContextBase<'_, &Positioned<SelectionSet>>, _field: &Positioned<Field>, ) -> Result<ConstValue, ServerError>
Resolve an output value to
async_graphql::Value.Sourcefn qualified_type_name() -> String
fn qualified_type_name() -> String
Qualified typename.
Sourceimpl PartialOrd for U128
impl PartialOrd for U128
Sourceimpl ScalarType for U128
impl ScalarType for U128
Sourcefn parse(value: ConstValue) -> Result<U128, InputValueError<U128>>
fn parse(value: ConstValue) -> Result<U128, InputValueError<U128>>
Parse a scalar value.
Sourcefn to_value(&self) -> ConstValue
fn to_value(&self) -> ConstValue
Convert the scalar to
Value.Sourceimpl Serialize for U128
impl Serialize for U128
Sourcefn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
fn serialize<S>(
&self,
serializer: S,
) -> Result<<S as Serializer>::Ok, <S as Serializer>::Error>where
S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for U128
impl Eq for U128
impl StructuralPartialEq for U128