pub struct MessagePolicy {
pub blanket: BlanketMessagePolicy,
pub restrict_chain_ids_to: Option<HashSet<ChainId>>,
pub ignore_chain_ids: HashSet<ChainId>,
pub reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>,
pub reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>,
pub process_events_from_application_ids: Option<HashSet<GenericApplicationId>>,
pub never_reject_application_ids: HashSet<GenericApplicationId>,
}Expand description
Policies for automatically handling incoming messages.
Fields
blanket: BlanketMessagePolicyThe blanket policy applied to all messages.
restrict_chain_ids_to: Option<HashSet<ChainId>>A collection of chains which restrict the origin of messages to be
accepted. Option::None means that messages from all chains are accepted. An empty
HashSet denotes that messages from no chains are accepted.
ignore_chain_ids: HashSet<ChainId>A collection of chains whose incoming messages should be ignored.
reject_message_bundles_without_application_ids: Option<HashSet<GenericApplicationId>>A collection of applications: If Some, only bundles with at least one message by any
of these applications will be accepted.
reject_message_bundles_with_other_application_ids: Option<HashSet<GenericApplicationId>>A collection of applications: If Some, only bundles all of whose messages are by these
applications will be accepted.
process_events_from_application_ids: Option<HashSet<GenericApplicationId>>A collection of applications: If Some, only event streams from those
applications will be processed.
never_reject_application_ids: HashSet<GenericApplicationId>A collection of applications whose messages must never be rejected. Bundles whose
messages are all from one of these applications bypass the other rejection rules
(except restrict_chain_ids_to), and on execution failure they are discarded for
later retry instead of being rejected. A bundle that contains any message from an
application not on this list can be rejected. An empty set disables this feature.
Implementations
Sourceimpl MessagePolicy
impl MessagePolicy
pub async fn blanket( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&BlanketMessagePolicy, Error>
pub async fn restrict_chain_ids_to( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&Option<HashSet<ChainId>>, Error>
pub async fn ignore_chain_ids( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&HashSet<ChainId>, Error>
pub async fn reject_message_bundles_without_application_ids( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&Option<HashSet<GenericApplicationId>>, Error>
pub async fn reject_message_bundles_with_other_application_ids( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&Option<HashSet<GenericApplicationId>>, Error>
pub async fn process_events_from_application_ids( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&Option<HashSet<GenericApplicationId>>, Error>
pub async fn never_reject_application_ids( &self, ctx: &ContextBase<'_, &Positioned<Field>>, ) -> Result<&HashSet<GenericApplicationId>, Error>
Sourceimpl MessagePolicy
impl MessagePolicy
Sourcepub fn ignores_origin(&self, origin: &ChainId) -> bool
pub fn ignores_origin(&self, origin: &ChainId) -> bool
Returns true if every message from origin would be unconditionally dropped:
blanket policy is Ignore, the origin is in ignore_chain_ids, or
restrict_chain_ids_to is Some and does not contain the origin.